@@ -2,7 +2,14 @@ import yaml
 from os.path import expanduser, isfile
 import os
 
+getsecret_overrides = {}
+
+def setsecret(key, value):
+  getsecret_overrides[key] = value
+
 def getsecret(key, default=None):
+  if key in getsecret_overrides:
+    return getsecret_overrides[key]
   environ_value = os.environ.get(key)
   if environ_value is not None:
     return environ_value
